Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
arrakis_server/__init__.py | 5 | 3 | 0 | 40.0%
arrakis_server/__main__.py | 71 | 71 | 0 | 0.0%
arrakis_server/arrow.py | 43 | 18 | 0 | 58.1%
arrakis_server/backends/__init__.py | 16 | 3 | 0 | 81.2%
arrakis_server/backends/mock/__init__.py | 94 | 36 | 0 | 61.7%
arrakis_server/backends/mock/channels/__init__.py | 0 | 0 | 0 | 100.0%
arrakis_server/channel.py | 21 | 2 | 0 | 90.5%
arrakis_server/constants.py | 2 | 0 | 0 | 100.0%
arrakis_server/errors.py | 16 | 4 | 0 | 75.0%
arrakis_server/metadata.py | 94 | 16 | 9 | 83.0%
arrakis_server/partition.py | 64 | 0 | 0 | 100.0%
arrakis_server/schemas.py | 21 | 3 | 0 | 85.7%
arrakis_server/scope.py | 129 | 32 | 0 | 75.2%
arrakis_server/server.py | 224 | 71 | 0 | 68.3%
arrakis_server/traits.py | 38 | 4 | 16 | 89.5%
Total | 838 | 263 | 25 | 68.6%

No items found using the specified filter.